@@ -16,22 +16,63 @@
 #include "buffer.h"
 #include "bus.h"
 #include "caps.h"
+#include "childproxy.h"
 #include "clock.h"
 #include "element.h"
+#include "elementfactory.h"
 #include "enums.h"
 #include "error.h"
 #include "event.h"
+#include "filter.h"
 #include "format.h"
+#include "index.h"
+#include "ghostpad.h"
+#include "indexfactory.h"
+#include "interface.h"
 #include "iterator.h"
 #include "message.h"
 #include "pad.h"
 #include "padtemplate.h"
+#include "parse.h"
 #include "pipeline.h"
+#include "plugin.h"
+#include "pluginfeature.h"
+#include "preset.h"
 #include "query.h"
+#include "registry.h"
+#include "segment.h"
 #include "structure.h"
 #include "systemclock.h"
+#include "taglist.h"
+#include "tagsetter.h"
+#include "task.h"
+#include "urihandler.h"
 #include "value.h"
 #include "xml.h"
+#include "basesrc.h"
+#include "basesink.h"
+#include "basetransform.h"
+#include "pushsrc.h"
+#include "audioclock.h"
+#include "audiofilter.h"
+#include "audiosink.h"
+#include "audiosrc.h"
+#include "baseaudiosink.h"
+#include "baseaudiosrc.h"
+#include "cddabasesrc.h"
+#include "videosink.h"
+#include "colorbalance.h"
+#include "colorbalancechannel.h"
+#include "mixer.h"
+#include "mixeroptions.h"
+#include "mixertrack.h"
+#include "navigation.h"
+#include "propertyprobe.h"
+#include "tuner.h"
+#include "tunerchannel.h"
+#include "tunernorm.h"
+#include "videoorientation.h"
+#include "xoverlay.h"
 
 extern "C"
 {
